@@ -23,15 +23,15 @@ alpha = {
     'sr-RS@latin': '^[A-ZČĆŽŠĐ]+$',
     'sr-RS': '^[А-ЯЂЈЉЊЋЏ]+$',
     'sv-SE': '^[A-ZÅÄÖ]+$',
-    'th-TH': '^[ก-๐\s]+$',
+    'th-TH': r'^[ก-๐\s]+$',
     'tr-TR': '^[A-ZÇĞİıÖŞÜ]+$',
     'uk-UA': '^[А-ЩЬЮЯЄIЇҐі]+$',
     'vi-VN': '^[A-ZÀÁẠẢÃÂẦẤẬẨẪĂẰẮẶẲẴĐÈÉẸẺẼÊỀẾỆỂỄÌÍỊỈĨÒÓỌỎÕÔỒỐỘỔỖƠỜỚỢỞỠÙÚỤỦŨƯỪỨỰỬỮỲÝỴỶỸ]+$',
     'ku-IQ': '^[ئابپتجچحخدرڕزژسشعغفڤقکگلڵمنوۆھەیێيطؤثآإأكضصةظذ]+$',
     'ar': '^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]+',
     'he': '^[א-ת]+',
-    'fa': '^[\'آاءأؤئبپتثجچحخدذرزژسشصضطظعغفقکگلمنوهةی\']+$',
-    'hi-IN': '^[\u0900-\u0961]+[\u0972-\u097F]*$',
+    'fa': r'^[\'آاءأؤئبپتثجچحخدذرزژسشصضطظعغفقکگلمنوهةی\']+$',
+    'hi-IN': r'^[\u0900-\u0961]+[\u0972-\u097F]*$',
 }
 
 alphanumeric = {
@@ -58,15 +58,15 @@ alphanumeric = {
     'sr-RS@latin': '^[0-9A-ZČĆŽŠĐ]+$',
     'sr-RS': '^[0-9А-ЯЂЈЉЊЋЏ]+$',
     'sv-SE': '^[0-9A-ZÅÄÖ]+$',
-    'th-TH': '^[ก-๙\s]+$',
+    'th-TH': r'^[ก-๙\s]+$',
     'tr-TR': '^[0-9A-ZÇĞİıÖŞÜ]+$',
     'uk-UA': '^[0-9А-ЩЬЮЯЄIЇҐі]+$',
     'ku-IQ': '^[٠١٢٣٤٥٦٧٨٩0-9ئابپتجچحخدرڕزژسشعغفڤقکگلڵمنوۆھەیێيطؤثآإأكضصةظذ]+$',
     'vi-VN': '^[0-9A-ZÀÁẠẢÃÂẦẤẬẨẪĂẰẮẶẲẴĐÈÉẸẺẼÊỀẾỆỂỄÌÍỊỈĨÒÓỌỎÕÔỒỐỘỔỖƠỜỚỢỞỠÙÚỤỦŨƯỪỨỰỬỮỲÝỴỶỸ]+$',
     'ar': '^[٠١٢٣٤٥٦٧٨٩0-9ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]+',
     'he': '^[0-9א-ת]+',
-    'fa': '^[\'0-9آاءأؤئبپتثجچحخدذرزژسشصضطظعغفقکگلمنوهةی۱۲۳۴۵۶۷۸۹۰\']+$',
-    'hi-IN': '^[\u0900-\u0963]+[\u0966-\u097F]*$',
+    'fa': r'^[\'0-9آاءأؤئبپتثجچحخدذرزژسشصضطظعغفقکگلمنوهةی۱۲۳۴۵۶۷۸۹۰\']+$',
+    'hi-IN': r'^[\u0900-\u0963]+[\u0966-\u097F]*$',
 }
 
 decimal = {
