@@ -7,6 +7,6 @@ from .utils.to_int import to_int
 
 def is_divisible_by(input: str, num: Union[int, float, str]) -> bool:
     assert_string(input)
-    if to_float(input) != None and to_int(num) != None:
+    if to_float(input) is not None and to_int(num) is not None:
         return (to_float(input) % to_int(num)) == 0
     return False
