@@ -38,7 +38,7 @@ def is_url(input: str, options={}) -> bool:
                 domains_pattern = domain.strip()
             else:
                 domains_pattern = f"{domains_pattern}|{domain}"
-        domains_pattern = f"(?=.*({domains_pattern})\.)"
+        domains_pattern = rf"(?=.*({domains_pattern})\.)"
 
     top_level_domain_pattern = ""
 
@@ -48,16 +48,16 @@ def is_url(input: str, options={}) -> bool:
                 top_level_domain_pattern = domain.strip()
             else:
                 top_level_domain_pattern = f"{top_level_domain_pattern}|{domain}"
-        top_level_domain_pattern = f"(\.({top_level_domain_pattern}))"
+        top_level_domain_pattern = rf"(\.({top_level_domain_pattern}))"
     else:
         top_level_domain_pattern = r"\.[a-z]{2,63}"
 
-    protocol_pattern = "" if options["no_scheme"] else r"((http(s)?):\/\/)?"
+    protocol_pattern = "" if options["no_scheme"] else r"((http(s)?)://)?"
 
     limit_domain_length = "{1,255}"
     base_url_pattern = fr"{protocol_pattern}(www\.)?(?!-)[(\-a-z0-9.]{limit_domain_length}[a-z0-9]{top_level_domain_pattern}"
 
-    path_pattern = r"\/?" if options["with_no_path"] else r"\b(\/[-a-zA-Z0-9()@:%_\+.~#?&//=]*)?"
+    path_pattern = r"/?" if options["with_no_path"] else r"\b(/[-a-zA-Z0-9()@:%_\+.~#?&//=]*)?"
 
     pattern = fr"^({domains_pattern}{base_url_pattern}{path_pattern})$"
 
